%define anolis_release 2

%bcond_without check

# https://github.com/containerd/containerd
%global goipath         github.com/containerd/containerd
Version:                1.6.19

%gometa

%global goname          containerd
%global godevelname     containerd-devel

%global common_description %{expand:
Containerd is an industry-standard container runtime with an emphasis on
simplicity, robustness and portability. It is available as a daemon for Linux
and Windows, which can manage the complete container lifecycle of its host
system: image transfer and storage, container execution and supervision,
low-level storage and network attachments, etc.}

%global golicenses      LICENSE NOTICE
%global godocs          docs ROADMAP.md SCOPE.md code-of-conduct.md\\\
                        BUILDING.md README.md RELEASES.md

Name:           %{goname}
Release:        %{anolis_release}%{?dist}
Summary:        Open and reliable container runtime

# Upstream license specification: Apache-2.0
License:        ASL 2.0
URL:            %{gourl}
Source0:        %{gosource}
Source1:        containerd.service
Source2:        containerd.toml
# Carve out code requiring github.com/Microsoft/hcsshim
Patch0:         0001-Revert-commit-for-Windows-metrics.patch
Patch1:         0002-Remove-windows-only-dep.patch

BuildRequires:  btrfs-progs-devel
BuildRequires:  systemd-rpm-macros
BuildRequires:  go-md2man

Requires:       runc

%description
%{common_description}

%gopkg

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%goprep -k
%autopatch -p1
# Used only for generation:
rm -rf cmd/protoc-gen-gogoctrd

%build
export LDFLAGS="-X %{goipath}/version.Version=%{version} "
for cmd in cmd/* ; do
  %gobuild -o %{gobuilddir}/bin/$(basename $cmd) %{goipath}/$cmd
done
mkdir _man
go-md2man -in docs/man/containerd-config.8.md -out _man/containerd-config.8
go-md2man -in docs/man/containerd-config.toml.5.md -out _man/containerd-config.toml.5
%{gobuilddir}/bin/gen-manpages containerd.8 _man
%{gobuilddir}/bin/gen-manpages ctr.8 _man
rm %{gobuilddir}/bin/gen-manpages

%install
install -m 0755 -vd                     %{buildroot}%{_bindir}
install -m 0755 -vp %{gobuilddir}/bin/* %{buildroot}%{_bindir}/
install -D -p -m 0644 _man/containerd.8 %{buildroot}%{_mandir}/man8/containerd.8
install -D -p -m 0644 _man/containerd-config.8 %{buildroot}%{_mandir}/man8/containerd-config.8
install -D -p -m 0644 _man/ctr.8 %{buildroot}%{_mandir}/man8/ctr.8
install -D -p -m 0644 _man/containerd-config.toml.5 %{buildroot}%{_mandir}/man5/containerd-config.toml.5
install -D -p -m 0644 %{S:1} %{buildroot}%{_unitdir}/containerd.service
install -D -p -m 0644 %{S:2} %{buildroot}%{_sysconfdir}/containerd/config.toml

%post
%systemd_post containerd.service

%preun
%systemd_preun containerd.service

%postun
%systemd_postun_with_restart containerd.service

%if %{with check}
%check
%gocheck -d pkg/cri/server -t integration
%endif

%generate_compatibility_deps

%files
%license LICENSE NOTICE

%{_bindir}/*
%dir %{abidir}
%{abidir}/*-option.list
%{_mandir}/man8/containerd.8*
%{_mandir}/man8/containerd-config.8*
%{_mandir}/man8/ctr.8*
%{_mandir}/man5/containerd-config.toml.5*
%{_unitdir}/containerd.service
%dir %{_sysconfdir}/containerd
%config(noreplace) %{_sysconfdir}/containerd/config.toml

%files doc
%doc docs ROADMAP.md SCOPE.md code-of-conduct.md BUILDING.md
%doc README.md RELEASES.md

%changelog
* Tue Apr 04 2023 Chunmei Xu <xuchunmei@linux.alibaba.com> - 1.6.19-2
- build with local vendor and do not provide devel subpackage

* Tue Mar 07 2023 yuanhui <yuanhui@linux.alibaba.com> - 1.6.19-1
- Update to v1.6.19
- Add abi and doc files

* Thu Mar 10 2022 Yuanhong Peng <yummypeng@linux.alibaba.com> - 1.5.9-1
- Init from upstream v1.5.9
